@@ -16,12 +16,14 @@ file "LICENSE" for more information.
 
 import inspect
 import os
-from   os import path
+from   os.path import exists, isdir, isfile, join, dirname, relpath, realpath
+from   os.path import splitext
 import shutil
 import subprocess
 import sys
 import tempfile
 import webbrowser
+from   validator_collection.checkers import is_url
 
 if __debug__:
     from sidetrack import log
@@ -49,15 +51,15 @@ def writable(dest):
             return False
         return True
 
-    if path.exists(dest) and not path.isdir(dest):
+    if exists(dest) and not isdir(dest):
         # Path is an existing file.
         return os.access(dest, os.F_OK | os.W_OK)
-    elif path.isdir(dest):
+    elif isdir(dest):
         # Path itself is an existing directory.  Is it writable?
         return dir_writable(dest)
     else:
         # Path is a file but doesn't exist yet. Can we write to the parent dir?
-        return dir_writable(path.dirname(dest))
+        return dir_writable(dirname(dest))
 
 
 def nonempty(dest):
@@ -66,18 +68,18 @@ def nonempty(dest):
 
 
 def files_in_directory(dir, extensions = None, recursive = True):
-    if not path.isdir(dir):
+    if not isdir(dir):
         return []
     if not readable(dir):
         return []
     if __debug__: log(f'reading directory {dir}')
     files = []
     for item in os.listdir(dir):
-        full_path = path.join(dir, item)
-        if path.isfile(full_path) and readable(full_path):
+        full_path = join(dir, item)
+        if isfile(full_path) and readable(full_path):
             if not extensions or filename_extension(item) in extensions:
                 files.append(full_path)
-        elif path.isdir(full_path) and recursive:
+        elif isdir(full_path) and recursive:
             files += files_in_directory(full_path, extensions)
     return sorted(files)
 
@@ -102,10 +104,10 @@ def alt_extension(filepath, ext):
     '''Returns the 'filepath' with the extension replaced by 'ext'.  The
     extension given in 'ext' should NOT have a leading period: that is, it
     should be "foo", not ".foo".'''
-    return path.splitext(filepath)[0] + '.' + ext
+    return splitext(filepath)[0] + '.' + ext
 
 
-def filter_by_extensions(item_list, endings):
+def filtered_by_extensions(item_list, endings):
     if not item_list:
         return []
     if not endings:
@@ -123,11 +125,16 @@ def relative(file):
     argument is actuall a file path, it will return it unchanged.'''
     if is_url(file):
         return file
-    candidate = path.relpath(file, os.getcwd())
-    if not candidate.startswith('../..'):
-        return candidate
+    try:
+        # This can fail on Windows if we're on a network-mapped drive.
+        candidate = relpath(file, os.getcwd())
+    except Exception as ex:
+        return file
     else:
-        return path.realpath(candidate)
+        if not candidate.startswith('../..'):
+            return candidate
+        else:
+            return realpath(candidate)
 
 
 def rename_existing(file):
@@ -147,11 +154,11 @@ def rename_existing(file):
                 if __debug__: log(f'failed to delete {backup}')
                 if __debug__: log(f'failed to rename {file} to {backup}')
 
-    if path.exists(file):
+    if exists(file):
         rename(file)
         return
-    full_path = path.join(os.getcwd(), file)
-    if path.exists(full_path):
+    full_path = join(os.getcwd(), file)
+    if exists(full_path):
         rename(full_path)
         return
 
@@ -159,7 +166,7 @@ def rename_existing(file):
 def delete_existing(file):
     '''Delete the given file.'''
     # Check if it's actually a directory.
-    if path.isdir(file):
+    if isdir(file):
         if __debug__: log(f'doing rmtree on directory {file}')
         try:
             shutil.rmtree(file)
@@ -178,7 +185,7 @@ def file_in_use(file):
     '''Returns True if the given 'file' appears to be in use.  Note: this only
     works on Windows, currently.
     '''
-    if not path.exists(file):
+    if not exists(file):
         return False
     if sys.platform.startswith('win'):
         # This is a hack, and it really only works for this purpose on Windows.
