@@ -23,8 +23,8 @@ import urllib
 if __debug__:
     from sidetrack import log
 
-from .exceptions import *
 from .interrupt import wait, interrupted
+from .exceptions import *
 
 
 # Internal constants.
@@ -114,7 +114,7 @@ def timed_request(method, url, client = None, **kwargs):
         return f'{text} for {url}'
 
     if client is None:
-        timeout = httpx.Timeout(connect = 15, read = 15, write = 15)
+        timeout = httpx.Timeout(15, connect = 15, read = 15, write = 15)
         client = httpx.Client(timeout = timeout, http2 = True, verify = False)
 
     failures = 0
@@ -132,12 +132,11 @@ def timed_request(method, url, client = None, **kwargs):
                 return response
             else:
                 failures += 1
-        except (KeyboardInterrupt, UserCancelled) as ex:
+        except KeyboardInterrupt as ex:
             if __debug__: log(addurl(f'network {method} interrupted by {str(ex)}'))
             raise
-        except (httpx.CookieConflict, httpx.StreamError, httpx.ProxyError,
-                httpx.DecodingError, httpx.ProtocolError,
-                httpx.RequestBodyUnavailable, httpx.TooManyRedirects) as ex:
+        except (httpx.CookieConflict, httpx.StreamError, httpx.TooManyRedirects,
+                httpx.DecodingError, httpx.ProtocolError, httpx.ProxyError) as ex:
             # Probably indicates a deeper issue.  Don't do our lengthy retry
             # sequence, but try one more time, in case it's transient.
             if __debug__: log(addurl(f'exception {str(ex)}'))
@@ -204,6 +203,11 @@ def net(method, url, client = None, handle_rate = True,
     This method always passes the argument allow_redirects = True to the
     underlying Python HTTPX library network calls.
     '''
+    known_methods = ['get', 'post', 'head', 'options', 'put', 'delete', 'patch']
+    if method.lower() not in known_methods:
+        raise ValueError(f'HTTP method "{method}" is not'
+                         f' one of {", ".join(known_methods)}.')
+
     def addurl(text):
         return f'{text} for {url}'
 
